@@ -3,7 +3,7 @@
 #' We provide tools for an isotropic spherical normal (SN) distributions on 
 #' a \eqn{(p-1)}-sphere in \eqn{\mathbf{R}^p} for sampling, density evaluation, and maximum likelihood estimation 
 #' of the parameters where the density is defined as
-#' \deqn{f_SN(x; \mu, \lambda) = \frac{1}{Z(\lambda)} \exp \left( -\frac{\lambda}{2} d^2(x,\mu) \right)}
+#' \deqn{f_{SN}(x; \mu, \lambda) = \frac{1}{Z(\lambda)} \exp \left( -\frac{\lambda}{2} d^2(x,\mu) \right)}
 #' for location and concentration parameters \eqn{\mu} and \eqn{\lambda} respectively and the normalizing constant \eqn{Z(\lambda)}.
 #' 
 #' 
@@ -12,7 +12,7 @@
 #' @param log a logical; \code{TRUE} to return log-density, \code{FALSE} for densities without logarithm applied.
 #' @param lambda a concentration parameter that is positive.
 #' @param n the number of samples to be generated.
-#' @param method an algorithm name for concentration parameter estimation.i
+#' @param method an algorithm name for concentration parameter estimation. It should be one of \code{"Newton"},\code{"Halley"},\code{"Optimize"}, and \code{"DE"} (case sensitive).
 #' @param ... extra parameters for computations, including\describe{
 #' \item{maxiter}{maximum number of iterations to be run (default:50).}
 #' \item{eps}{tolerance level for stopping criterion (default: 1e-5).}
@@ -62,6 +62,10 @@
 #' par(opar)
 #' }
 #' 
+#' @references 
+#' \insertRef{hauberg_2018_DirectionalStatisticsSpherical}{Riemann}
+#' 
+#' \insertRef{you_2022_ParameterEstimationModelbased}{Riemann}
 #' 
 #' @name spnorm
 #' @concept distribution
@@ -190,10 +194,18 @@ mle.spnorm <- function(data, method=c("Newton","Halley","Optimize","DE"), ...){
   x      = sp2mat(spobj)
   pars   = list(...)
   pnames = names(pars)
-  myiter = max(50, ifelse(("maxiter"%in%pnames), pars$maxiter, 50))
-  myeps  = min(1e-6, max(0, ifelse(("eps"%in%pnames), as.double(pars$eps), 1e-6)))
-  alldip = c("newton","halley","optimize","de")
-  myway  = match.arg(tolower(method), alldip)
+  
+  if ("maxiter"%in%pnames){
+    myiter = max(10, round(pars$maxiter))
+  } else {
+    myiter = 50
+  }
+  if ("eps"%in%pnames){
+    myeps = min(1e-6, max(0, as.double(pars$eps)))
+  } else {
+    myeps = 1e-6
+  }
+  myway = tolower(match.arg(method))
   
   ## STEP 1. INTRINSIC MEAN
   N = length(spobj$data)
@@ -234,7 +246,7 @@ lambda_method_halley <- function(data, mean, myiter, myeps){
         return(exp(-lbd*(r^2)/2)*((sin(r))^(D-2)))
       }
       t1 = 2*(pi^((D-1)/2))/gamma((D-1)/2) # one possible source of error
-      t2 = stats::integrate(myfunc, lower=0, upper=pi, rel.tol=sqrt(.Machine$double.eps))$value
+      t2 = stats::integrate(myfunc, lower=sqrt(.Machine$double.eps), upper=pi, rel.tol=sqrt(.Machine$double.eps))$value
       return(t1*t2)
     }
     myfun <- function(r){
@@ -321,7 +333,7 @@ lambda_method_newton <- function(data, mean, myiter, myeps){
         return(exp(-lbd*(r^2)/2)*((sin(r))^(D-2)))
       }
       t1 = 2*(pi^((D-1)/2))/gamma((D-1)/2) # one possible source of error
-      t2 = stats::integrate(myfunc, lower=0, upper=pi, rel.tol=sqrt(.Machine$double.eps))$value
+      t2 = stats::integrate(myfunc, lower=sqrt(.Machine$double.eps), upper=pi, rel.tol=sqrt(.Machine$double.eps))$value
       return(t1*t2)
     }
     myfun <- function(r){
@@ -338,7 +350,7 @@ lambda_method_newton <- function(data, mean, myiter, myeps){
       myfunc <- function(r){
         return(exp(-lbd*(r^2)/2)*((sin(r))^(D-2)))
       }
-      return(stats::integrate(myfunc, lower=0, upper=pi, rel.tol=sqrt(.Machine$double.eps))$value)
+      return(stats::integrate(myfunc, lower=sqrt(.Machine$double.eps), upper=pi, rel.tol=sqrt(.Machine$double.eps))$value)
     }
     myfun <- function(r){
       return(exp(-lambda*(r^2)/2)*((sin(r))^(D-2)))
@@ -396,7 +408,7 @@ lambda_method_opt <- function(data, mean, myiter, myeps){
         return(exp(-lbd*(r^2)/2)*((sin(r))^(D-2)))
       }
       t1 = 2*(pi^((D-1)/2))/gamma((D-1)/2) # one possible source of error
-      t2 = stats::integrate(myfunc, lower=0, upper=pi, rel.tol=sqrt(.Machine$double.eps))$value
+      t2 = stats::integrate(myfunc, lower=sqrt(.Machine$double.eps), upper=pi, rel.tol=sqrt(.Machine$double.eps))$value
       return(t1*t2)
     }
     myfun <- function(r){
@@ -430,7 +442,7 @@ lambda_method_DE <- function(data, mean, myiter, myeps){
         return(exp(-lbd*(r^2)/2)*((sin(r))^(D-2)))
       }
       t1 = 2*(pi^((D-1)/2))/gamma((D-1)/2) # one possible source of error
-      t2 = stats::integrate(myfunc, lower=0, upper=pi, rel.tol=sqrt(.Machine$double.eps))$value
+      t2 = stats::integrate(myfunc, lower=sqrt(.Machine$double.eps), upper=pi, rel.tol=sqrt(.Machine$double.eps))$value
       return(t1*t2)
     }
     myfun <- function(r){
@@ -532,7 +544,7 @@ dspnorm.constant <- function(lbd, D){ # lbd : lambda / D : dimension
     return(exp(-lbd*(r^2)/2)*((sin(r))^(D-2)))
   }
   t1 = 2*(pi^((D-1)/2))/gamma((D-1)/2) # one possible source of error
-  t2 = stats::integrate(myfunc, lower=0, upper=pi, rel.tol=sqrt(.Machine$double.eps))$value
+  t2 = stats::integrate(myfunc, lower=sqrt(.Machine$double.eps), upper=pi, rel.tol=sqrt(.Machine$double.eps))$value
   return(t1*t2)
 }
 
